API
===

In the future, when the API is more established, we will support a few
functions, that provided the filename and the extension, will attempt to infer
which plugin to call. For now, these functions do nothing.

.. automodule:: redpil
    :members:
    :undoc-members:
    :show-inheritance:

redpil.bmp module
-----------------

.. automodule:: redpil.bmp
    :members:
    :undoc-members:
    :show-inheritance:
